from mteb.models import ModelMeta, sentence_transformers_loader

kowshik24_bangla_embedding_model = ModelMeta(
    loader=sentence_transformers_loader,
    name="Kowshik24/bangla-sentence-transformer-ft-matryoshka-paraphrase-multilingual-mpnet-base-v2",
    model_type=["dense"],
    languages=["ben-Beng"],  # Bengali using Bengali script
    open_weights=True,
    revision="6689c21e69be5950596bad084457cbaa138728d8",
    release_date="2025-11-10",
    n_parameters=278043648,
    n_embedding_parameters=192_001_536,
    memory_usage_mb=1061,
    embed_dim=768,
    license="apache-2.0",
    max_tokens=128,
    reference="https://huggingface.co/Kowshik24/bangla-sentence-transformer-ft-matryoshka-paraphrase-multilingual-mpnet-base-v2",
    similarity_fn_name="cosine",
    framework=["Sentence Transformers", "PyTorch", "safetensors"],
    use_instructions=False,
    public_training_code="https://github.com/kowshik24/Bangla-Embedding",
    public_training_data="https://huggingface.co/datasets/sartajekram/BanglaRQA",
    training_datasets=set(),
    citation="""@inproceedings{reimers-2019-sentence-bert,
    title = "Sentence-BERT: Sentence Embeddings using Siamese BERT-Networks",
    author = "Reimers, Nils and Gurevych, Iryna",
    booktitle = "Proceedings of the 2019 Conference on Empirical Methods in Natural Language Processing",
    month = "11",
    year = "2019",
    publisher = "Association for Computational Linguistics",
    url = "https://arxiv.org/abs/1908.10084",
}""",
)
