from .cmteb_classification import (
    IFlyTek,
    IFlyTekV2,
    JDReview,
    JDReviewV2,
    MultilingualSentiment,
    MultilingualSentimentV2,
    OnlineShopping,
    TNews,
    TNewsV2,
    Waimai,
    WaimaiV2,
)
from .yue_openrice_review_classification import (
    YueOpenriceReviewClassification,
    YueOpenriceReviewClassificationV2,
)

__all__ = [
    "IFlyTek",
    "IFlyTekV2",
    "JDReview",
    "JDReviewV2",
    "MultilingualSentiment",
    "MultilingualSentimentV2",
    "OnlineShopping",
    "TNews",
    "TNewsV2",
    "Waimai",
    "WaimaiV2",
    "YueOpenriceReviewClassification",
    "YueOpenriceReviewClassificationV2",
]
